==> piwigo-2.1.6.zip: piwigo/language/no_NO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installasjon';
$lang['Basic configuration'] = 'Grunnleggende konfigurasjon';
$lang['Default gallery language'] = 'Standard galleri språk';
$lang['Database configuration'] = 'Database konfigurasjon';
$lang['Admin configuration'] = 'Admin konfigurasjon';
$lang['Start Install'] = 'Start installasjon';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail addresse må være lik xxx@yyy.eee (eksempel : jack@altern.org)';
$lang['Webmaster login'] = 'Webmaster innlogging';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det vil vises for besøkende. Det er nødvendig med side administrasjon';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Tilkobling til server er ok, men tilkobling til databasen er ikke mulig';
$lang['Can\'t connect to server'] = 'Kan ikke koble til server';
$lang['Database type'] = 'Database type';
$lang['The type of database your piwigo data will be store in'] = 'Type database dine Piwigo data vil bli lagret i';
$lang['Host'] = 'Host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'bruker (user)';
$lang['user login given by your host provider'] = 'bruker (user) innlogging gitt av din web tilbyder';
$lang['Password'] = 'Passord';
$lang['user password given by your host provider'] = 'bruker (user) passord gitt av din web tilbyder';
$lang['Database name'] = 'Database navn';
$lang['also given by your host provider'] = 'også gitt av din web tilbyder';
$lang['Database table prefix'] = 'Database tabellers prefix';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'database tabellers navn kommer til å få prefix (gjør deg i bedre stand til å behandle tabellene)';
$lang['enter a login for webmaster'] = 'skriv et brukernavn for webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmasters brukernavn kan ikke inneholde tegn som \' eller "';
$lang['please enter your password again'] = 'vennligst skriv passord igjen';
$lang['Webmaster password'] = 'Webmaster passord';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hold det hemmelig, dette gir deg tilgang til administrasjons panelet';
$lang['Password [confirm]'] = 'Passord [bekreft]';
$lang['verification'] = 'verifisering';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Trenger du hjelp? Still et spørsmål på <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmasters mail addresse';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besøkende vil kunne bruke denne mailen for å kontakte side administrator.';
$lang['PHP 5 is required'] = 'PHP 5 er nødvendig';
$lang['It appears your webhost is currently running PHP %s.'] = 'Det kan se ut som om din leverandør kjører PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve å endre din konfigurasjon til PHP 5 ved å lage eller modifisere en .htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Merk, du kan endre din konfigurasjon selv og restarte Piwigo etter dette.';
$lang['Try to configure PHP 5'] = 'Prøve å konfigurere PHP 5';
$lang['Sorry!'] = 'Beklager!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo var ikke i stand til å konfigurere PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Du kan sjekke din web tilbyder\'e support og se om du kan endre til PHP 5 selv.';
$lang['Hope to see you back soon.'] = 'Håper vi sees snart.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulerer, Piwigo installasjonen er ferdig';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ løsning er å kopiere teksten fra tekst boksen over og lime det inn i filen "local/config/database.inc.php" (Advarsel: database.inc.php må kun inneholde hva som ligger i tekstområdet, ingen ny linje eller mellomrom)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Opprettelse av konfig fil local/config/database.inc.php feilet.';
$lang['Download the config file'] = 'Last ned konfig fil';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan laste ned konfig filen og laste den opp til local/config mappen i din installasjon.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite og PostgreSQL er foreløpig i en eksperimentell fase.';
$lang['Learn more'] = 'Lær mer';

?>

==> piwigo-2.2.5.zip: piwigo/language/no_NO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installasjon';
$lang['Basic configuration'] = 'Grunnleggende konfigurasjon';
$lang['Default gallery language'] = 'Standard galleri språk';
$lang['Database configuration'] = 'Database konfigurasjon';
$lang['Admin configuration'] = 'Admin konfigurasjon';
$lang['Start Install'] = 'Start installasjon';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail addresse må være lik xxx@yyy.eee (eksempel : jack@altern.org)';
$lang['Webmaster login'] = 'Webmaster innlogging';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det vil vises for besøkende. Det er nødvendig med side administrasjon';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Tilkobling til server er ok, men tilkobling til databasen er ikke mulig';
$lang['Can\'t connect to server'] = 'Kan ikke koble til server';
$lang['Database type'] = 'Database type';
$lang['The type of database your piwigo data will be store in'] = 'Type database dine Piwigo data vil bli lagret i';
$lang['Host'] = 'Host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'bruker (user)';
$lang['user login given by your host provider'] = 'bruker (user) innlogging gitt av din web tilbyder';
$lang['Password'] = 'Passord';
$lang['user password given by your host provider'] = 'bruker (user) passord gitt av din web tilbyder';
$lang['Database name'] = 'Database navn';
$lang['also given by your host provider'] = 'også gitt av din web tilbyder';
$lang['Database table prefix'] = 'Database tabellers prefix';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'database tabellers navn kommer til å få prefix (gjør deg i bedre stand til å behandle tabellene)';
$lang['enter a login for webmaster'] = 'skriv et brukernavn for webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmasters brukernavn kan ikke inneholde tegn som \' eller "';
$lang['please enter your password again'] = 'vennligst skriv passord igjen';
$lang['Webmaster password'] = 'Webmaster passord';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hold det hemmelig, dette gir deg tilgang til administrasjons panelet';
$lang['Password [confirm]'] = 'Passord [bekreft]';
$lang['verification'] = 'verifisering';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Trenger du hjelp? Still et spørsmål på <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmasters mail addresse';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besøkende vil kunne bruke denne mailen for å kontakte side administrator.';
$lang['PHP 5 is required'] = 'PHP 5 er nødvendig';
$lang['It appears your webhost is currently running PHP %s.'] = 'Det kan se ut som om din leverandør kjører PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve å endre din konfigurasjon til PHP 5 ved å lage eller modifisere en .htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Merk, du kan endre din konfigurasjon selv og restarte Piwigo etter dette.';
$lang['Try to configure PHP 5'] = 'Prøve å konfigurere PHP 5';
$lang['Sorry!'] = 'Beklager!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo var ikke i stand til å konfigurere PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Du kan sjekke din web tilbyder\'e support og se om du kan endre til PHP 5 selv.';
$lang['Hope to see you back soon.'] = 'Håper vi sees snart.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulerer, Piwigo installasjonen er ferdig';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ løsning er å kopiere teksten fra tekst boksen over og lime det inn i filen "local/config/database.inc.php" (Advarsel: database.inc.php må kun inneholde hva som ligger i tekstområdet, ingen ny linje eller mellomrom)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Opprettelse av konfig fil local/config/database.inc.php feilet.';
$lang['Download the config file'] = 'Last ned konfig fil';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan laste ned konfig filen og laste den opp til local/config mappen i din installasjon.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite og PostgreSQL er foreløpig i en eksperimentell fase.';
$lang['Learn more'] = 'Lær mer';

?>
